.. include:: ../README.rst
   :end-before: github-only

.. _Contributor Guide: contributing.html
.. _Usage: usage.html

.. toctree::
   :hidden:
   :maxdepth: 1

   usage
   reference
   contributing
   Code of Conduct <codeofconduct>
   License <license>
   Changelog <https://github.com/laserkelvin/astrochem_embedding/releases>
